@@ -90,11 +90,7 @@ class DecoderDialog(QDialog):
 
         # Connects
         self.create_connects()
-
-        try:
-            self.restoreGeometry(settings.read("{}/geometry".format(self.__class__.__name__)))
-        except TypeError:
-            pass
+        self.restoreGeometry(settings.read("{}/geometry".format(self.__class__.__name__), type=bytes))
 
     def create_connects(self):
         self.ui.inpt.textChanged.connect(self.decoder_update)
